@@ -21,10 +21,9 @@ from basis.cli.services.organizations import (
     get_organization_by_name,
     paginated_organizations,
 )
-from basis.cli.services.output import prompt_str, sprint, prompt_choices
+from basis.cli.services.output import prompt_choices
 from basis.configuration.base import load_yaml
-from basis.graph.builder import graph_manifest_from_yaml
-from basis.graph.configured_node import GraphManifest
+from basis.configuration.graph import GraphDefinitionCfg
 
 
 @dataclass
@@ -38,6 +37,7 @@ class IdLookup:
     explicit_graph_version_id: str = None
     ignore_local_cfg: bool = False
     explicit_graph_name: str = None
+    find_nearest_graph: bool = False
 
     @cached_property
     def organization_id(self) -> str:
@@ -105,16 +105,12 @@ class IdLookup:
             node_path = node.absolute().relative_to(graph.parent)
         except Exception as e:
             raise Exception(err_msg) from e
-        node_id = next(
-            (
-                n.id
-                for n in self.manifest.nodes
-                if Path(n.file_path_to_node_script_relative_to_root) == node_path
-            ),
-            None,
-        )
-        if node_id:
-            return node_id
+        cfg = GraphDefinitionCfg(**(load_yaml(graph) or {}))
+        for node in cfg.nodes:
+            if node.node_file == node_path.as_posix():
+                if node.id:
+                    return node.id
+                raise Exception("Node is not deployed")
         raise Exception(err_msg)
 
     @cached_property
@@ -122,8 +118,16 @@ class IdLookup:
         if self.explicit_graph_path:
             return resolve_graph_path(self.explicit_graph_path, exists=True)
         if self.node_file_path:
-            return find_graph_file(self.node_file_path.parent, prompt=False)
-        return find_graph_file(path=None, prompt=True)
+            return find_graph_file(
+                self.node_file_path.parent,
+                prompt=False,
+                nearest=self.find_nearest_graph,
+            )
+        return find_graph_file(path=None, prompt=True, nearest=self.find_nearest_graph)
+
+    @cached_property
+    def graph_directory(self) -> Path:
+        return self.graph_file_path.parent
 
     @cached_property
     def cfg(self) -> CliConfig:
@@ -145,7 +149,3 @@ class IdLookup:
             vid = self.explicit_graph_version_id
             return get_graph_version_by_id(vid)["graph"]["name"]
         return from_yaml()
-
-    @cached_property
-    def manifest(self) -> GraphManifest:
-        return graph_manifest_from_yaml(self.graph_file_path)
