@@ -1,20 +1,18 @@
 from __future__ import annotations
 
+import functools
 import io
 import re
 from io import StringIO
 from pathlib import Path
-from typing import List, Dict, Any, Optional, Union, IO
+from typing import List, Dict, Any, Optional, Union, IO, Iterator, Callable
 from zipfile import ZipFile, ZipInfo
 
 import ruyaml
 
-from basis.cli.helpers import compress_directory
+from basis.cli.helpers import compress_directory, random_node_id
 from basis.cli.services.graph import resolve_graph_path
 from basis.configuration.graph import NodeCfg, ExposingCfg, GraphDefinitionCfg
-from basis.configuration.path import NodeId
-from basis.graph.builder import _GraphBuilder, graph_manifest_from_yaml
-from basis.graph.configured_node import GraphManifest
 
 MISSING = object()
 
@@ -45,11 +43,12 @@ class GraphConfigEditor:
                 text = f.read()
             self._cfg = self._yaml.load(text) or {}
             # ruyaml doesn't provide a way to preserve indentation,
-            # so pick a value that matches the first list item we see
-            if m := re.search(r"^( *)-", text, re.MULTILINE):
-                indent = len(m.group(1)) + 2
-            else:
-                indent = 4
+            # so pick a value that matches the least-indented list item we see.
+            matches = (
+                len(m.group(1)) for m in re.finditer(r"^( *)-", text, re.MULTILINE)
+            )
+            # ruyaml's indent number includes the length  of "- " for some reason
+            indent = min(matches, default=2) + 2
         else:
             self._cfg = {}
             indent = 4
@@ -72,25 +71,6 @@ class GraphConfigEditor:
         """Parse the data to a GraphDefinitionCfg without writing it to disk"""
         return GraphDefinitionCfg(**self._cfg)
 
-    def parse_to_manifest(self) -> GraphManifest:
-        """Parse the data to a GraphManifest without writing it to disk"""
-        parse_to_cfg = self.parse_to_cfg
-        path_to_graph_yml = self._path_to_graph_yml
-
-        class MemBuilder(_GraphBuilder):
-            def _read_graph_yml(self, path: Path) -> GraphDefinitionCfg:
-                if path_to_graph_yml and path != path_to_graph_yml:
-                    return super()._read_graph_yml(path)
-                if path != self.root_graph_location:
-                    raise NotImplementedError("Cannot construct subgraphs in-memory")
-                return parse_to_cfg()
-
-        if path_to_graph_yml:
-            p = path_to_graph_yml
-        else:
-            p = Path(self.get_name() or "graph") / "graph.yml"
-        return MemBuilder(p).build()
-
     def set_name(self, name: str) -> GraphConfigEditor:
         self._cfg["name"] = name
         return self
@@ -136,6 +116,25 @@ class GraphConfigEditor:
         self._cfg["nodes"].append(d)
         return self
 
+    def remove_node_with_id(
+        self, node_id: str, default_id: Callable[[dict], str] = lambda _: {}
+    ) -> GraphConfigEditor:
+        """Remove node entry with a given id value
+
+        Raise a KeyError if no such nodes exist
+        You can pass a default_id function that returns ids for node entries that don't
+        have them defined.
+        """
+        for i, node in enumerate(self._nodes()):
+            id = node["id"] if "id" in node else default_id(node)
+            if id == node_id:
+                del self._cfg["nodes"][i]
+                break
+        else:
+            raise KeyError(node_id)
+
+        return self
+
     def add_node(
         self,
         node_file: str,
@@ -148,7 +147,7 @@ class GraphConfigEditor:
         description: str = None,
     ) -> GraphConfigEditor:
         if id is MISSING:
-            id = NodeId.random()
+            id = random_node_id()
         self.add_node_cfg(
             NodeCfg(
                 node_file=node_file,
@@ -171,7 +170,7 @@ class GraphConfigEditor:
         description: str = None,
     ) -> GraphConfigEditor:
         if id is MISSING:
-            id = NodeId.random()
+            id = random_node_id()
         self.add_node_cfg(
             NodeCfg(
                 webhook=webhook,
@@ -182,6 +181,23 @@ class GraphConfigEditor:
         )
         return self
 
+    def add_missing_node_ids(self) -> GraphConfigEditor:
+        """Add a random id to any node entry that doesn't specify one"""
+        for node in self._nodes():
+            if "id" not in node:
+                node["id"] = random_node_id()
+        return self
+
+    def _nodes(self) -> Iterator[dict]:
+        nodes = self._cfg.get("nodes")
+        if not isinstance(nodes, list):
+            return
+
+        for node in nodes:
+            if not isinstance(node, dict):
+                continue
+            yield node
+
 
 class GraphDirectoryEditor:
     def __init__(self, graph_path: Path, overwrite: bool = False):
@@ -197,20 +213,21 @@ class GraphDirectoryEditor:
         self.dir = self.yml_path.parent
         self.overwrite = overwrite
         if self.yml_path.is_file():
-            self._cfg = GraphConfigEditor(self.yml_path)
+            self._cfg = self._editor(self.yml_path)
         else:
-            self._cfg = None
+            self._cfg: Optional[GraphConfigEditor] = None
+
+    def graph_name(self) -> str:
+        """Return the name of the graph"""
+        name = None
+        if self._cfg:
+            name = self._cfg.get_name()
+        return name or self.yml_path.parent.name
 
     def compress_directory(self) -> io.BytesIO:
         """Return an in-memory zip file containing the compressed graph directory"""
         return compress_directory(self.dir)
 
-    def build_manifest(self, allow_errors: bool = False) -> GraphManifest:
-        """Build a graph manifest from the graph directory"""
-        if self._cfg:
-            self._cfg.write()
-        return graph_manifest_from_yaml(self.yml_path, allow_errors=allow_errors)
-
     def add_node_from_file(self, dst_path: Union[Path, str], file: IO[bytes]):
         """Write the content of a file to dst_path
 
@@ -242,6 +259,16 @@ class GraphDirectoryEditor:
                 self._add(src_path, dst_path, f)
         return self
 
+    def add_missing_node_ids(self) -> GraphDirectoryEditor:
+        """Add a random id to any node entry that doesn't specify one
+
+        This will update all graph.yml files in the directory
+        """
+        for editor in self._graph_editors():
+            editor.add_missing_node_ids()
+            editor.write()
+        return self
+
     def _add(self, src_path: Path, dst_path: Path, zf: ZipFile):
         if src_path.name == "graph.yml":
 
@@ -299,6 +326,14 @@ class GraphDirectoryEditor:
                     )
         full_dst_path.write_text(new_content)
 
+    def _graph_editors(self) -> Iterator[GraphConfigEditor]:
+        for p in self.dir.rglob("graph.yml"):
+            yield self._editor(p)
+
+    @functools.lru_cache(maxsize=None)
+    def _editor(self, yaml_path: Path) -> GraphConfigEditor:
+        return GraphConfigEditor(yaml_path)
+
 
 class FileOverwriteError(Exception):
     def __init__(self, file_path: Path, message: str) -> None:
